==> haskell-cereal-0.5.8.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cereal
version:              0.5.8.1
visibility:           public
id:                   cereal-0.5.8.1-56yg04wGStN22upOSM9put
key:                  cereal-0.5.8.1-56yg04wGStN22upOSM9put
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
author:
    Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
    Galois Inc.,
    Lemmih <lemmih@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            provisional
homepage:             https://github.com/GaloisInc/cereal
synopsis:             A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.

category:             Data, Parsing
abi:                  412da6584e71eaae1d02bf7294bfec99
exposed:              True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put

import-dirs:          /usr/lib/ghc-8.10.2/site-local/cereal-0.5.8.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cereal-0.5.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cereal-0.5.8.1
hs-libraries:         HScereal-0.5.8.1-56yg04wGStN22upOSM9put
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.10.0 containers-0.6.2.1
    ghc-prim-0.6.1

haddock-interfaces:   /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html:         /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cereal-0.5.8.1-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cereal
version:              0.5.8.1
visibility:           public
id:                   cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
key:                  cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
author:
    Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
    Galois Inc.,
    Lemmih <lemmih@gmail.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            provisional
homepage:             https://github.com/GaloisInc/cereal
synopsis:             A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.

category:             Data, Parsing
abi:                  f50ef6fb6f14d9be3e496493c5b75ae4
exposed:              True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put

import-dirs:          /usr/lib/ghc-8.10.4/site-local/cereal-0.5.8.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/cereal-0.5.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/cereal-0.5.8.1
hs-libraries:         HScereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    ghc-prim-0.6.1

haddock-interfaces:   /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html:         /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
